/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/// <reference types="node" />
import { EventEmitter } from "events";
import { IConsumer, IQueuedMessage, IPartitionLambdaFactory, ILogger, LambdaCloseType } from "@fluidframework/server-services-core";
/**
 * Partition of a message stream. Manages routing messages to individual handlers. And then maintaining the
 * overall partition offset.
 */
export declare class Partition extends EventEmitter {
    private readonly id;
    private readonly logger?;
    private readonly config?;
    private readonly q;
    private lambdaP;
    private lambda;
    private readonly checkpointManager;
    private readonly context;
    private closed;
    constructor(id: number, factory: IPartitionLambdaFactory, consumer: IConsumer, logger?: ILogger | undefined, config?: any);
    process(rawMessage: IQueuedMessage): void;
    close(closeType: LambdaCloseType): void;
    /**
     * Stops processing on the partition
     */
    drain(): Promise<void>;
}
//# sourceMappingURL=partition.d.ts.map